<?php

/**
 * @file
 * The accessible module admininstration interface.
 *
 */ 

define('ACCESSIBLE_FIX_GOOGLE_CSE_LABEL_DEFAULT', 'Search');
define('ACCESSIBLE_FIX_GOOGLE_CSE_LABEL_POSITION_OFF_SCREEN_DEFAULT', 1);

define('ACCESSIBLE_FIX_SEARCH_LABEL_DEFAULT', 'Search');
define('ACCESSIBLE_FIX_SEARCH_LABEL_POSITION_OFF_SCREEN_DEFAULT', 0);

define('ACCESSIBLE_FIX_OFFSCREEN_BLOCK_HEADINGS_DEFAULT', FALSE);


/**
 * Admin form for Accessible Fix module.
 *
 * @param $form_state
 *   A form state array.
 * @param $sid
 *   A LDAP server ID.
 *
 * @return
 *   The form structure.
 */
function accessible_fix_admin_edit(&$form_state, $op) {

  if ($op == "edit" || $op == NULL) {

      $form['accessible_fix']['general'] = array(
        '#type' => 'fieldset',
        '#title' => t('General Settings'),
        '#collapsible' => TRUE,
        '#collapsed' => ! ($edit['accessible_fix_google_cse_label']  != ACCESSIBLE_FIX_GOOGLE_CSE_LABEL_DEFAULT
            || $edit['accessible_fix_google_cse_label_position_off_screen'] != ACCESSIBLE_FIX_GOOGLE_CSE_LABEL_POSITION_OFF_SCREEN_DEFAULT),
      );


    $form['accessible_fix']['general']['accessible_fix_offscreen_block_headings'] = array(
        '#type' => 'checkbox',
        '#title' => 'Offscreen Block Headings ',
        '#size' => 10,
        '#description' => t('Allow block administrators to class block heading (h2,h3, etc) as "offscreen".  This will only work if block theming template is modified.
        Sample block.tpl.php file(s) are available in the accessible/examples folder.'),
        '#default_value' =>  variable_get('accessible_offscreen_block_headings', ACCESSIBLE_FIX_OFFSCREEN_BLOCK_HEADINGS_DEFAULT)
      );
      
    if (module_exists("google_cse")) {
      $form['accessible_fix']['google_cse'] = array(
        '#type' => 'fieldset',
        '#title' => t('Google CSE Additional Configuration'),
        '#collapsible' => TRUE,
        '#collapsed' => ! ($edit['accessible_fix_google_cse_label']  != ACCESSIBLE_FIX_GOOGLE_CSE_LABEL_DEFAULT
            || $edit['accessible_fix_google_cse_label_position_off_screen'] != ACCESSIBLE_FIX_GOOGLE_CSE_LABEL_POSITION_OFF_SCREEN_DEFAULT),
      );

      $form['accessible_fix']['google_cse']['accessible_fix_google_cse_label'] = array(
        '#type' => 'textfield',
        '#title' => 'Label to use on Google CSE search input. ',
        '#size' => 10,
        '#description' => t('If you are using it Google CSE.  May be positioned off screen for accessibility.  Defaults is: ' ) . ACCESSIBLE_FIX_GOOGLE_CSE_LABEL_DEFAULT,
        '#default_value' =>  variable_get('accessible_fix_google_cse_label', ACCESSIBLE_FIX_GOOGLE_CSE_LABEL_DEFAULT)
      );

      $form['accessible_fix']['google_cse']['accessible_fix_google_cse_label_position_off_screen'] = array(
        '#type' => 'checkbox',
        '#title' => t('Position Google CSE Label off screen'),
        '#description' => t('If you are using Google CSE, should label be positioned off screen.'),
        '#default_value' =>  variable_get('accessible_fix_google_cse_label_position_off_screen', ACCESSIBLE_FIX_GOOGLE_CSE_LABEL_POSITION_OFF_SCREEN_DEFAULT)
      );
    }


    if (module_exists("search")) {
      $form['accessible_fix']['search'] = array(
        '#type' => 'fieldset',
        '#title' => t('Search Block Additional Configuration'),
        '#collapsible' => TRUE,
        '#collapsed' => ! ($edit['accessible_fix_search_label']  != ACCESSIBLE_FIX_SEARCH_LABEL_DEFAULT
            || $edit['accessible_fix_search_label_position_off_screen'] != ACCESSIBLE_FIX_SEARCH_LABEL_POSITION_OFF_SCREEN_DEFAULT),
      );

      $form['accessible_fix']['search']['accessible_fix_search_label'] = array(
        '#type' => 'textfield',
        '#title' => 'Label to use on search input. ',
        '#size' => 10,
        '#description' => t('If you are using search module.  May be positioned off screen for accessibility.  Defaults is: ' ) . ACCESSIBLE_FIX_SEARCH_LABEL_DEFAULT,
        '#default_value' =>  variable_get('accessible_fix_search_label', ACCESSIBLE_FIX_SEARCH_LABEL_DEFAULT)
      );

      $form['accessible_fix']['search']['accessible_fix_search_label_position_off_screen'] = array(
        '#type' => 'checkbox',
        '#title' => t('Position Search Label off screen'),
        '#description' => t('If you are using search, should label be positioned off screen.'),
        '#default_value' =>  variable_get('accessible_fix_search_label_position_off_screen', ACCESSIBLE_FIX_SEARCH_LABEL_POSITION_OFF_SCREEN_DEFAULT)
      );
    }



    $form['buttons']['submit'] = array(
      '#type' => 'submit',
      '#value' => t('Update'),
    );

    return $form;
  }
  else {
    drupal_goto('admin/settings/accessible/accessible_fix');
  }
}

/**
 * Submit hook for the admin settings form.
 */
function accessible_fix_admin_edit_submit($form, &$form_state) {
  $values = $form_state['values'];

  if ($values['op'] == t('Reset') && $values['confirm'] == 1) {
      variable_set('accessible_fix_google_cse_label', ACCESSIBLE_FIX_GOOGLE_CSE_LABEL_DEFAULT);
      variable_set('accessible_fix_google_cse_label_position_off_screen', ACCESSIBLE_FIX_GOOGLE_CSE_LABEL_POSITION_OFF_SCREEN_DEFAULT);
      variable_set('accessible_fix_search_label', ACCESSIBLE_FIX_SEARCH_LABEL_DEFAULT);
      variable_set('accessible_fix_search_label_position_off_screen', ACCESSIBLE_FIX_SEARCH_LABEL_POSITION_OFF_SCREEN_DEFAULT);
      variable_set('accessible_fix_offscreen_block_headings', ACCESSIBLE_FIX_OFFSCREEN_BLOCK_HEADINGS_DEFAULT);
    drupal_set_message(t('The configuration options have been reset to their default values.'));
  }
  else {

    $values = $form_state['values'];
    variable_set('accessible_fix_offscreen_block_headings',  $values['accessible_fix_offscreen_block_headings']);
    
    if ($values['accessible_fix_offscreen_block_headings'] && (! db_column_exists('blocks', 'offscreen'))) {
      db_add_field($ret, 'blocks', 'offscreen', array(
        'type' => 'int',
        'size' => 'tiny',
        'not null' => TRUE,
        'default' => '0',
      ));
    }
    if (module_exists("google_cse")) {
      variable_set('accessible_fix_google_cse_label',  $values['accessible_fix_google_cse_label']);
      variable_set('accessible_fix_google_cse_label_position_off_screen',  $values['accessible_fix_google_cse_label_position_off_screen']);
    }

    if (module_exists("search")) {
      variable_set('accessible_fix_search_label',  $values['accessible_fix_search_label']);
      variable_set('accessible_fix_search_label_position_off_screen',  $values['accessible_fix_search_label_position_off_screen']);
    }

    drupal_set_message(t('The configuration options have been saved.'));
  }

  $form_state['redirect'] = 'admin/settings/accessible/accessible_fix';
}

